@@ -23,8 +23,8 @@ describe <- function(.data, ...) {
 #' \item n : number of observations excluding missing values
 #' \item na : number of missing values
 #' \item mean : arithmetic average
-#' \item sd : standard devation
-#' \item se_mean : standrd error mean. sd/sqrt(n)
+#' \item sd : standard deviation
+#' \item se_mean : standard error mean. sd/sqrt(n)
 #' \item IQR : interquartile range (Q3-Q1)
 #' \item skewness : skewness
 #' \item kurtosis : kurtosis
@@ -126,7 +126,9 @@ describe_impl <- function(df, vars) {
     
     cnt_complete <- sum(complete.cases(x))
     
-    numsum <- as_tibble(matrix(NA, ncol = length(vname) + 2, nrow = 1))
+    numsum <- matrix(NA, ncol = length(vname) + 2, nrow = 1,
+                     dimnames = list(NULL, paste0("C", seq(length(vname) + 2))))
+    numsum <- as_tibble(numsum)
     
     if (cnt_complete >= 4) {
       result <- RcmdrMisc::numSummary(x, statistics = stats,
@@ -160,7 +162,7 @@ describe_impl <- function(df, vars) {
                       function(x) num_summary(pull(df, x)))
 
   tibble(variable = vars[idx_numeric], statistic) %>%
-    tidyr::unnest()
+    tidyr::unnest(cols = c(statistic))
 }
 
 
@@ -248,7 +250,7 @@ describe_group_impl <- function(df, vars, margin) {
   statistic <- lapply(vars[idx_numeric], function(x) call_summary(x))
 
   desc <- tibble(statistic) %>%
-    tidyr::unnest()
+    tidyr::unnest(cols = c(statistic))
 
   desc
 }
