@@ -110,9 +110,9 @@ transform <- function(x, method = c("zscore", "minmax", "log", "log+1", "sqrt",
 #' @param object an object of class "transform", usually, a result of a call to transform().
 #' @param ... further arguments passed to or from other methods.
 #' @details
-#' summary.transform compares the distribution of data before and after data conversion.
+#' summary.transform compares the distribution of data before and after data transformation.
 #'
-#' @seealso \code{\link{transform}}, \code{\link{summary.transform}}.
+#' @seealso \code{\link{transform}}, \code{\link{plot.transform}}.
 #' @examples
 #' # Generate data for the example
 #' carseats <- ISLR::Carseats
@@ -166,7 +166,7 @@ summary.transform <- function(object, ...) {
 #'
 #' @description
 #' Visualize two kinds of plot by attribute of `transform` class.
-#' The Transformation of a numerical variable is a density plot.
+#' The transformation of a numerical variable is a density plot.
 #'
 #' @param x an object of class "transform", usually, a result of a call to transform().
 #' @param ... arguments to be passed to methods, such as graphical parameters (see par).
@@ -205,7 +205,7 @@ plot.transform <- function(x, ...) {
     filter(key == "original") %>%
     ggplot(aes(x = value)) +
     geom_density(na.rm = TRUE) +
-    ggtitle("Oraginal Data") +
+    ggtitle("Original Data") +
     theme(plot.title = element_text(hjust = 0.5))
 
   fig2 <- df %>%
@@ -221,7 +221,7 @@ plot.transform <- function(x, ...) {
 
 #' Reporting the information of transformation
 #'
-#' @description The transformation_report() report the information of transformate
+#' @description The transformation_report() report the information of transform
 #' numerical variables for object inheriting from data.frame.
 #'
 #' @details Generate transformation reports automatically.
@@ -278,7 +278,7 @@ plot.transform <- function(x, ...) {
 #' "html" create html file by rmarkdown::render().
 #' @param output_file name of generated file. default is NULL.
 #' @param output_dir name of directory to generate report file. default is tempdir().
-#' @param font_family charcter. font family name for figure in pdf.
+#' @param font_family character. font family name for figure in pdf.
 #' @param browse logical. choose whether to output the report results to the browser.
 #'
 #' @examples
@@ -293,12 +293,13 @@ plot.transform <- function(x, ...) {
 #' transformation_report(carseats)
 #' # create pdf file. file name is Transformation_Report.pdf
 #' transformation_report(carseats, US)
-#' # create pdf file. file name is Transformation.pdf
-#' transformation_report(carseats, "US", output_file = "Transformation.pdf")
+#' # create pdf file. file name is Transformation_carseats.pdf
+#' transformation_report(carseats, "US", output_file = "Transformation_carseats.pdf")
 #' # create html file. file name is Transformation_Report.html
 #' transformation_report(carseats, "US", output_format = "html")
-#' # create html file. file name is Transformation.html
-#' transformation_report(carseats, US, output_format = "html", output_file = "Transformation.html")
+#' # create html file. file name is Transformation_carseats
+#' transformation_report(carseats, US, output_format = "html", 
+#'                       output_file = "Transformation_carseats.html")
 #' }
 #'
 #' @importFrom knitr knit2pdf
@@ -306,7 +307,6 @@ plot.transform <- function(x, ...) {
 #' @importFrom grDevices cairo_pdf
 #' @importFrom gridExtra grid.arrange
 #' @importFrom xtable xtable
-#' @importFrom moments skewness kurtosis
 #' @importFrom knitr kable
 #' @importFrom prettydoc html_pretty
 #' @importFrom kableExtra kable_styling
